'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.default = enableGracefulClose;
var defaultOptions = {
  timeout: 10 * 1000, // 10 seconds HEROKU DEFAULT
  sigterm: true
};

function enableGracefulClose(server, userOptions, callback) {
  if (typeof userOptions === 'function') {
    return enableGracefulClose(server, {}, userOptions);
  }

  var options = _extends({}, defaultOptions, userOptions);

  var connections = new Set();
  var closing = false;

  server.on('connection', function (connection) {
    connections.add(connection);
    connection.on('close', function () {
      return connections.delete(connection);
    });
  });

  function close() {
    if (closing) {
      callback(new Error('Server closing is already in the progress'));
      return;
    }

    closing = true;

    var timeoutId = setTimeout(function () {
      timeoutId = null;

      var _iteratorNormalCompletion = true;
      var _didIteratorError = false;
      var _iteratorError = undefined;

      try {
        for (var _iterator = connections[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
          var connection = _step.value;

          connection.end();
        }
      } catch (err) {
        _didIteratorError = true;
        _iteratorError = err;
      } finally {
        try {
          if (!_iteratorNormalCompletion && _iterator.return) {
            _iterator.return();
          }
        } finally {
          if (_didIteratorError) {
            throw _iteratorError;
          }
        }
      }

      connections.clear();
    }, options.timeout);

    // server can be opened and closed again
    server.close(function () {
      closing = false;

      if (timeoutId) {
        clearTimeout(timeoutId);
        timeoutId = null;
      }

      // end process
      if (!callback) {
        process.exit(0);
      }

      // add user ability to close his things
      callback(function () {
        process.exit(0);
      });
    });
  }

  if (options.sigterm) {
    process.on('SIGTERM', close);
  }

  return close;
}